[gtk+] scale: Use more succinct names for style classes



commit 4151cb1202a120a0eae6da04d45411dafbfaa317
Author: Matthias Clasen <mclasen redhat com>
Date:   Thu May 19 09:44:25 2016 -0400

    scale: Use more succinct names for style classes
    
    Use .marks-before/after to indicate the presence of marks.
    As Lapo points out, compatibility with the previous names
    is not really that important, since everything else changed
    around it.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=766440

 gtk/gtkscale.c |   14 +++++++-------
 1 files changed, 7 insertions(+), 7 deletions(-)
---
diff --git a/gtk/gtkscale.c b/gtk/gtkscale.c
index 5b3ff9b..61e2275 100644
--- a/gtk/gtkscale.c
+++ b/gtk/gtkscale.c
@@ -76,7 +76,7 @@
  * # CSS nodes
  *
  * |[<!-- language="plain" -->
- * scale[.fine-tune][.scale-has-marks-above][.scale-has-marks-below]
+ * scale[.fine-tune][.marks-before][.marks-after]
  * ├── marks.top
  * │   ├── mark
  * │   ┊    ├── [label]
@@ -119,8 +119,8 @@
  * scale, the label subnode is the first when present. Otherwise, the indicator
  * subnode is the first.
  *
  * The main CSS node gets the 'scale-has-marks-above' and/or 'scale-has-marks-below'
  * style classes added depending on what marks are present.
  *
  * If the scale is displaying the value (see #GtkScale:draw-value), there is
  * subnode with name value.
@@ -2027,8 +2027,8 @@ gtk_scale_clear_marks (GtkScale *scale)
   g_clear_object (&priv->bottom_marks_gadget);
 
   context = gtk_widget_get_style_context (GTK_WIDGET (scale));
-  gtk_style_context_remove_class (context, GTK_STYLE_CLASS_SCALE_HAS_MARKS_BELOW);
-  gtk_style_context_remove_class (context, GTK_STYLE_CLASS_SCALE_HAS_MARKS_ABOVE);
+  gtk_style_context_remove_class (context, "marks-before");
+  gtk_style_context_remove_class (context, "marks-after");
 
   _gtk_range_set_stop_values (GTK_RANGE (scale), NULL, 0);
 
@@ -2199,9 +2199,9 @@ gtk_scale_add_mark (GtkScale        *scale,
 
   context = gtk_widget_get_style_context (GTK_WIDGET (scale));
   if (priv->top_marks_gadget)
-    gtk_style_context_add_class (context, GTK_STYLE_CLASS_SCALE_HAS_MARKS_ABOVE);
+    gtk_style_context_add_class (context, "marks-before");
   if (priv->bottom_marks_gadget)
-    gtk_style_context_add_class (context, GTK_STYLE_CLASS_SCALE_HAS_MARKS_BELOW);
+    gtk_style_context_add_class (context, "marks-after");
 
   gtk_widget_queue_resize (widget);
 }
@@ -119,8 +119,8 @@
  * subnode is the first.
  *
- * The main CSS node gets the 'scale-has-marks-above' and/or 'scale-has-marks-below'
- * style classes added depending on what marks are present.
+ * The main CSS node gets the 'marks-before' and/or 'marks-after' style classes
+ * added depending on what marks are present.
  *
  * If the scale is displaying the value (see #GtkScale:draw-value), there is


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]